==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitas",
    "An error occurred while loading activities" : "Terjadi kesalahan saat memuat aktivitas",
    "No activity yet" : "Belum ada aktivitas",
    "Load more activities" : "Muat aktivitas lainnya",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
    "{name} (invisible)" : "{name} (tersembunyi)",
    "{name} (restricted)" : "{name} (terbatas)",
    "in {path}" : "di {path}",
    "This stream will show events like additions, changes & shares" : "Stream ini akan menampilkan agenda seperti penambahan, perubahan & berbagi",
    "There are no events for this filter" : "Tidak ada agenda untuk penyaring ini",
    "Today" : "Hari Ini",
    "Yesterday" : "Kemarin",
    "Open file" : "Membuka berkas",
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s",
    "Your feed URL is invalid" : "URL feed Anda tidak sah",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "Settings have been updated." : "Pengaturan telah diperbarui",
    "All activities" : "Semua aktifitas",
    "By others" : "Oleh lainnya",
    "By you" : "Oleh Anda",
    "\"remote user\"" : "\"remote user\"",
    "Activity notification for %s" : "Notifikasi aktifitas untuk %s",
    "Hello %s" : "Helo %s",
    "Hello %s," : "Helo %s,",
    "There was some activity at %s" : "Terdapat beberapa aktifitas di %s",
    "_and %n more _::_and %n more _" : ["* dan %n lagi"],
    ", " : ", ",
    "%s and %s" : "%s dan %s",
    "Mail" : "Email",
    "Stream" : "Stream",
    "Activity feed" : "Feed aktivitas",
    "Send activity emails" : "Kirim email aktivitas",
    "Default settings" : "Pengaturan default",
    "Configure the default activity settings for new users." : "Konfigurasikan pengaturan aktivitas default untuk pengguna baru.",
    "List your own actions in the stream" : "Cantumkan tindakan anda dalam stream",
    "Notify about your own actions via email" : "Beritahukan tetang aksi oleh Anda via email",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu menyetal alamat email Anda sebelum Anda dapat menerima email pemberitahuan.",
    "Send emails:" : "Kirim email:",
    "As soon as possible" : "Secepatnya",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Pilih aktivitas yang ingin Anda dapatkan notifikasi email, dan mana yang harus muncul di aktivitas aplikasi.",
    "Choose which activities you want to see in your stream." : "Pilih aktivitas mana yang ingin Anda lihat di stream Anda.",
    "Settings" : "Pengaturan",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "RSS feed" : "RSS feed",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat",
    "Files" : "Berkas",
    "Activities" : "Aktivitas",
    "Home" : "Beranda",
    "Activity notification" : "Pemberitahuan aktivitas"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitas",
    "An error occurred while loading activities" : "Terjadi kesalahan saat memuat aktivitas",
    "No activity yet" : "Belum ada aktivitas",
    "Load more activities" : "Muat aktivitas lainnya",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
    "{name} (invisible)" : "{name} (tersembunyi)",
    "{name} (restricted)" : "{name} (terbatas)",
    "in {path}" : "di {path}",
    "This stream will show events like additions, changes & shares" : "Stream ini akan menampilkan agenda seperti penambahan, perubahan & berbagi",
    "There are no events for this filter" : "Tidak ada agenda untuk penyaring ini",
    "Today" : "Hari Ini",
    "Yesterday" : "Kemarin",
    "Open file" : "Membuka berkas",
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s",
    "Your feed URL is invalid" : "URL feed Anda tidak sah",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "Settings have been updated." : "Pengaturan telah diperbarui",
    "All activities" : "Semua aktifitas",
    "By others" : "Oleh lainnya",
    "By you" : "Oleh Anda",
    "\"remote user\"" : "\"remote user\"",
    "Activity notification for %s" : "Notifikasi aktifitas untuk %s",
    "Hello %s" : "Helo %s",
    "Hello %s," : "Helo %s,",
    "There was some activity at %s" : "Terdapat beberapa aktifitas di %s",
    "_and %n more _::_and %n more _" : ["* dan %n lagi"],
    ", " : ", ",
    "%s and %s" : "%s dan %s",
    "Mail" : "Email",
    "Stream" : "Stream",
    "This application enables users to view actions related to their files in Nextcloud." : "Aplikasi ini memungkinkan pengguna untuk melihat aksi yang terkait dengan file yang mereka simpan di NextCloud",
    "Activity feed" : "Feed aktivitas",
    "Send activity emails" : "Kirim email aktivitas",
    "Default settings" : "Pengaturan default",
    "Configure the default activity settings for new users." : "Konfigurasikan pengaturan aktivitas default untuk pengguna baru.",
    "List your own actions in the stream" : "Cantumkan tindakan anda dalam stream",
    "Notify about your own actions via email" : "Beritahukan tetang aksi oleh Anda via email",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu menyetal alamat email Anda sebelum Anda dapat menerima email pemberitahuan.",
    "Send emails:" : "Kirim email:",
    "As soon as possible" : "Secepatnya",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Pilih aktivitas yang ingin Anda dapatkan notifikasi email, dan mana yang harus muncul di aktivitas aplikasi.",
    "Choose which activities you want to see in your stream." : "Pilih aktivitas mana yang ingin Anda lihat di stream Anda.",
    "Settings" : "Pengaturan",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "RSS feed" : "RSS feed",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat",
    "Files" : "Berkas",
    "Activities" : "Aktivitas",
    "Home" : "Beranda",
    "Activity notification" : "Pemberitahuan aktivitas"
},
"nplurals=1; plural=0;");
